Class: Aws::CloudFrontKeyValueStore::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudFrontKeyValueStore::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudfrontkeyvaluestore/client.rb
Overview
An API client for CloudFrontKeyValueStore. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CloudFrontKeyValueStore::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_key(params = {}) ⇒ Types::DeleteKeyResponse
Deletes the key value pair specified by the key.
-
#describe_key_value_store(params = {}) ⇒ Types::DescribeKeyValueStoreResponse
Returns metadata information about Key Value Store.
-
#get_key(params = {}) ⇒ Types::GetKeyResponse
Returns a key value pair.
-
#list_keys(params = {}) ⇒ Types::ListKeysResponse
Returns a list of key value pairs.
-
#put_key(params = {}) ⇒ Types::PutKeyResponse
Creates a new key value pair or replaces the value of an existing key.
-
#update_keys(params = {}) ⇒ Types::UpdateKeysResponse
Puts or Deletes multiple key value pairs in a single, all-or-nothing operation.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
774 775 776 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 774 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
777 778 779 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 777 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 747 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudFrontKeyValueStore') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudfrontkeyvaluestore' context[:gem_version] = '1.37.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_key(params = {}) ⇒ Types::DeleteKeyResponse
Deletes the key value pair specified by the key.
513 514 515 516 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 513 def delete_key(params = {}, = {}) req = build_request(:delete_key, params) req.send_request() end |
#describe_key_value_store(params = {}) ⇒ Types::DescribeKeyValueStoreResponse
Returns metadata information about Key Value Store.
555 556 557 558 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 555 def describe_key_value_store(params = {}, = {}) req = build_request(:describe_key_value_store, params) req.send_request() end |
#get_key(params = {}) ⇒ Types::GetKeyResponse
Returns a key value pair.
593 594 595 596 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 593 def get_key(params = {}, = {}) req = build_request(:get_key, params) req.send_request() end |
#list_keys(params = {}) ⇒ Types::ListKeysResponse
Returns a list of key value pairs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
638 639 640 641 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 638 def list_keys(params = {}, = {}) req = build_request(:list_keys, params) req.send_request() end |
#put_key(params = {}) ⇒ Types::PutKeyResponse
Creates a new key value pair or replaces the value of an existing key.
683 684 685 686 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 683 def put_key(params = {}, = {}) req = build_request(:put_key, params) req.send_request() end |
#update_keys(params = {}) ⇒ Types::UpdateKeysResponse
Puts or Deletes multiple key value pairs in a single, all-or-nothing operation.
738 739 740 741 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 738 def update_keys(params = {}, = {}) req = build_request(:update_keys, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
767 768 769 |
# File 'lib/aws-sdk-cloudfrontkeyvaluestore/client.rb', line 767 def waiter_names [] end |